# Snap Firmware Version: 2.4.19
# Platform RF Engine(Device type): RF200
# Author: Hacker - DuinoMiteMegaAndy
# Application: Garage Door Status & Control Mesh Node 
# Date: 4/4/2012
# Bugs:
# GD limit switches bounce and gives double status readings 
# provide lockouts to prevent limit switch bounce. <-------<<<<<
# Note: Using monitor pin (interrupt) cannot be used on the garaged door limit switches!
# Added:
# RTC sw alarms - A1arm1 and Alarm2 with once, daily and weekly modes
# garage door open and close counters OK
# garage door activity 10 min. counter OK 
# garge door automatic closure at 1:00 am <-----<<<< not enabled yet
# security key and enable to RPC for garage door activation OK
# added 5 sec debounce for garage door <------<<<<< OK
# separate garage door activation functions to indentify who did it OK
# Fix GPIO RF200 references <------<<<<
# added GD counters logic OK

from synapse.switchboard import *
from synapse.platforms import *
#
# Global Variables
# --------------------------
# Node Addresses for RPC
# --------------------------
portalAddr = '\x00\x00\x01'        # Hard-coded address for Portal <------------<<<<<<<<
Mesh_Central_Addr = '\x5C\xCC\x18' # RF200 <-----------------<<<<<<<<<
HH1_Addr = '\x5C\xCC\xDD'          # RF200 <-----------------<<<<<<<<<
#---------------------------

# Global RTC DS3231 Time / Date - Integers - default bootup
# Note: The below defaults are also the default DS3231 real time clock registers defaults
# The below global variables will be overwritten by getTimeDate() function.

DS3231_RTC_ADDRESS = 0xD0 # slave address is (0)1101000 which shifts to 1101000(R/W)

DS3231_MONTH    = 1
DS3231_DATE     = 1
DS3231_YEAR     = 0
DS3231_HOURS    = 12
DS3231_MINUTES  = 0
DS3231_SECONDS  = 0
DS3231_DOW      = 1  # Day of week --> Sun = 1, Mon = 2
retries = 1
DOW_Str = ''
DOWx = 1

Alarm1_Month = 1
Alarm1_Date = 1
Alarm1_Year = 0
Alarm1_Hours = 12
Alarm1_Minutes = 0
Alarm1_Seconds = 0
Alarm1_DOW = 1
Alarm1_Enable = False
Alarm1_Mode = 0 # alarm mode 0 = only once, mode 1 = daily, 2 = weekly --> uses DOW

Alarm2_Month = 1
Alarm2_Date = 1
Alarm2_Year = 0
Alarm2_Hours = 12
Alarm2_Minutes = 0
Alarm2_Seconds = 0
Alarm2_DOW = 1
Alarm2_Enable = False
Alarm2_Mode = 0 # alarm mode 0 = only once, mode 1 = daily, 2 = weekly --> uses DOW

secondCounter1 = 0 # Prevents GD activation for 2 seconds
openLockout = False
closeLockout = False
allowControl = False

GD_Activity_Counter = 0
hook_1_sec_Counter = 0
GD_Open_Counter = 0
GD_Close_Counter = 0
GD_Open_Bounce_Timer = 0
GD_Close_Bounce_Timer = 0

HH1_S_Key = 0 

#
# Begin Hooks
@setHook(HOOK_STARTUP)
def onStartup():
    # Set pin 0 as a Piezo alert beep output 
    # use low power ma. device ONLY!
    # Outputs
    setPinDir(GPIO_0, True) #Piezo
    setPinDir(GPIO_9, True) #GD pulse Open/Close
    # Source mode 1=On 0=off (device neg tied to ground)
    writePin(GPIO_0, False)
    writePin(GPIO_9, False)
    # Inputs
    setPinDir(GPIO_3, False) #GD open limit switch
    setPinDir(GPIO_4, False) #GD close limit switch
    # Pullups/pulldowns
    setPinPullup(16, True) #pullups
    setPinPullup(17, True) 
   
    # Sound piezo on startup
    GD_Piezo_Pulse()
    # I2C GPIO_17/18 used for DS3231
    DS3231_initRTC() # <----- NEEDED--<<<<<  Init I2C RTC - no pullups
    
@setHook(HOOK_GPIN)
def onPin(pin, False):
    # Report that a watched input has been triggered 
    pass
                
def Test_GD_Open_Status():
    rpc(Mesh_Central_Addr,'GD_Open_Status')
    
def Test_GD_Close_Status():
    rpc(Mesh_Central_Addr,'GD_Close_Status')
            
@setHook(HOOK_10MS)
def doEvery10ms(tick):
    pass
    
    
@setHook(HOOK_100MS)    
def timer100msEvent(currentMs):
    global Alarm1_Enable
    global Alarm2_Enable
    global Alarm1_Mode
    global Alarm2_Mode
    
    global openLockout
    global closeLockout
    global GD_Open_Bounce_Timer
    global GD_Close_Bounce_Timer
  
    
    # for Garage door nasty debounce from limit switches
    GDo = readPin(GPIO_3) # open limit switch
    GDc = readPin(GPIO_4) # close limit switch
    
    
    if GDo == True:
        GD_Open_Bounce_Timer += 1  # start timer off limit switch
    if GDo == False:
        GD_Open_Bounce_Timer = 0   # stop timer on limit switch 
    if GDc == True:
        GD_Close_Bounce_Timer += 1 # start timer off limit switch 
    if GDc == False:
        GD_Close_Bounce_Timer = 0  # stop timer on limit switch
        
    # Garage door travel time  = 11 seconds <-----<<<
    
    if GD_Open_Bounce_Timer >= 50:  # hold timer
        GD_Open_Bounce_Timer = 50
    
    if GD_Close_Bounce_Timer >= 50: # hold timer
        GD_Close_Bounce_Timer = 50 
        
    # check for mid-travel after a 5 second delay off limit
    
    if  GD_Open_Bounce_Timer >= 50 and GD_Close_Bounce_Timer >= 50:
    
    # clear both lockouts (debounce)    
        openLockout = False
        closeLockout = False
        
    if  GD_Open_Bounce_Timer >= 50 and GDc == False:     
        openLockout = False
        
    if  GD_Close_Bounce_Timer >= 50 and GDo == False:
        closeLockout = False       
        
    #Check Alarm 1    
    if Alarm1_Enable == True and Alarm1_Mode == 0:
        x = chkAlarm1(0) #mode 0 - only once
        if x == True:
            print 'Alarm1 mode 0 (once) just tripped!'
            Alarm1_Enable = False # prevent multiple triggers (10x)
            
    if Alarm1_Enable == True and Alarm1_Mode == 1:
        x = chkAlarm1(1) #mode 1 - daily
        if x == True:
            print 'Alarm1 mode 1 (daily) just tripped!'
            Alarm1_Enable = False # prevent multiple triggers (10x)
            
    if Alarm1_Enable == True and Alarm1_Mode == 2:
        x = chkAlarm1(2) #mode 2 - weekly
        if x == True:
            print 'Alarm1 mode 2 (weekly) just tripped!'
            Alarm1_Enable = False # prevent multiple triggers (10x) 
            
    #Check Alarm 2    
    if Alarm2_Enable == True and Alarm2_Mode == 0:
        x = chkAlarm2(0) #mode 0 - only once
        if x == True:
            print 'Alarm2 mode 0 (once) just tripped!'
            Alarm2_Enable = False # prevent multiple triggers (10x)
            
    if Alarm2_Enable == True and Alarm2_Mode == 1:
        x = chkAlarm2(1) #mode 1 - daily
        if x == True:
            print 'Alarm2 mode 1 (daily) just tripped!'
            Alarm2_Enable = False # prevent multiple triggers (10x)  
            
    if Alarm2_Enable == True and Alarm2_Mode == 2:
        x = chkAlarm2(2) #mode 2 - weekly
        if x == True:
            print 'Alarm2 mode 2 (weekly) just tripped!'
            Alarm2_Enable = False # prevent multiple triggers (10x)
            
@setHook(HOOK_1S)
def doEverySec(tick):
    global Alarm1_Enable
    global Alarm2_Enable
    global GD_Activity_Counter
    global hook_1_sec_Counter
    global GD_Open_Counter
    global GD_Close_Counter 
    global openLockout
    global closeLockout
    
    getTimeDate() # Read I2C time / date every second
    convertDOWtostr(DS3231_DOW) # convert dow nbr to str
    
    # System housekeeping
    if DS3231_HOURS == 23: # 12:55:0
        if DS3231_MINUTES == 55:
            if DS3231_MINUTES == 0:
                if Alarm1_Mode == 1 or Alarm1_Mode == 2:
                    Alarm1_Enable = True
                if Alarm2_Mode == 1 or Alarm2_Mode == 2:
                    Alarm2_Enable = True
            GD_Open_Counter = 0
            GD_Close_Counter = 0
            GD_Activity_Counter = 0         
    x = readPin(GPIO_3) # open limit switch
    hook_1_sec_Counter  += 1
    if hook_1_sec_Counter == 600: # 10 minutes reset
        GD_Activity_Counter = 0        
    if DS3231_HOURS == 1: # 1:0:0
        if DS3231_MINUTES == 0:
            if DS3231_MINUTES == 0:
                if GD_Activity_Counter > 0 and x == False:
                    GD_Activity_Counter = 0
                    #pulse_Activate_GD_2(True) <-----<<<<< automatic closure not enable yet!
    #GD_Piezo_Pulse()
    
    # read / poll garage door limit switches every second <--------------<<<<<<<<<
    # on POR / bootup / upload will always show the garage door open/close state.
    openLimit = readPin(GPIO_3) #open limit
    if openLimit == False and openLockout == False:
        openLockout = True
        rpc(Mesh_Central_Addr,'GD_Open_Status')
        GD_Activity_Counter += 1
        GD_Open_Counter += 1
            
    closeLimit = readPin(GPIO_4) #close limit
    if closeLimit == False and closeLockout == False:
        closeLockout = True
        rpc(Mesh_Central_Addr,'GD_Close_Status')
        GD_Close_Counter += 1

def clear_GD_Counters():
    global GD_Open_Counter
    global GD_Close_Counter
    GD_Open_Counter = 0
    GD_Close_Counter = 0 
        
def display_GD_Open_Counter():
    global GD_Open_Counter
    print GD_Open_Counter 
    
def display_GD_Close_Counter():
    global GD_Close_Counter
    print GD_Close_Counter 
    
def display_GD_10_min_Activity_Counter():
    global GD_Activity_Counter 
    print GD_Activity_Counter      
              
                
def GD_Piezo_ON():
    # Source mode 1=On 0=off 
    writePin(GPIO_0, True)
        
def GD_Piezo_Pulse():
    # Pulse the Piezo for 1000 msec.
    pulsePin(GPIO_0, 250, True) 
       
def GD_Piezo_OFF(): 
    # Source mode 1=On 0=off 
    writePin(GPIO_0, False)
               
def pulse_Activate_GD_1(allowControl,HH1_S_Key): # security key needed <-----<<<<
    global secondCounter1
    # Source mode 1=On 0=off
    if allowControl == True:
        if HH1_S_Key == 9: # Security Key for Hand Held 1
            pulsePin(GPIO_9, 500, True)
            rpc(Mesh_Central_Addr,'GD_Activate1')

def pulse_Activate_GD_2(allowControl): # no key needed!
    global secondCounter1
    # Source mode 1=On 0=off
    if allowControl == True:
        if HH1_S_Key == 9: # Security Key for Hand Held 1
            pulsePin(GPIO_9, 500, True)
            rpc(Mesh_Central_Addr,'GD_Activate2')         
        
def read_GD_Status():
    GD_Status = 0
    x1 = readPin(GPIO_3) #Open limit switch (False = open)
    x2 = readPin(GPIO_4) #Close limit switch (False = close)
    if x1 == False and x2 == False:
        GD_Status = 1
        rpc(Mesh_Central_Addr,'GD_Status',GD_Status)        
        rpc(HH1_Addr,'all_HH1_LEDS_On')
        return "GD Limit Switch Fatal Error"
    if x1 == True and x2 == True:
        GD_Status = 2
        rpc(Mesh_Central_Addr,'GD_Status',GD_Status)
        rpc(HH1_Addr,'all_HH1_LEDS_On')                
        return "GD is in travel or not fully Open"
    if x1 == False and x2 == True:
        GD_Status = 3
        rpc(Mesh_Central_Addr,'GD_Status',GD_Status)
        rpc(HH1_Addr,'HH1_red_On')                
        return "GD is Open"
    if x1 == True and x2 == False:
        GD_Status = 4
        rpc(Mesh_Central_Addr,'GD_Status',GD_Status)
        rpc(HH1_Addr,'HH1_grn_On')
        return "GD is Close"
    #--------------------------------------------------------------------
def buildRtcCmd(registerAddress, isRead):
    """internal helper routine"""
    slaveAddress = DS3231_RTC_ADDRESS
    if isRead:
        slaveAddress |= 1 # read
    cmd = ""
    cmd += chr( slaveAddress )
    cmd += chr( registerAddress )

    return cmd

def readClock(firstReg, numRegs):  # does not work ????  
    """read a string of registers from the RTC"""
    cmd = buildRtcCmd(firstReg, False)  
    i2cWrite(cmd, retries, False)  

    cmd = chr( DS3231_RTC_ADDRESS | 1 )
    result = i2cRead(cmd, numRegs, retries, False) 
             
    return result

def displayClockTime(): #Status: Ok
    Seconds = bcdToDec(readClockReg(0) & 0x7F)
    Minutes = bcdToDec(readClockReg(1))
    Hours   = bcdToDec(readClockReg(2) & 0x3F)    
    DOW     = bcdToDec(readClockReg(3))
       
    #eventString = "Hours = " + str(Hours)
    #rpc(portalAddr, "logEvent", eventString)
    
    #eventString = "Minutes = " + str(Minutes)
    #rpc(portalAddr, "logEvent", eventString)
    
    #eventString = "Seconds = " + str(Seconds)
    #rpc(portalAddr, "logEvent", eventString)
    
    #eventString = "Day of Week = " + str(DOW)
    #rpc(portalAddr, "logEvent", eventString)
    
    eventString = "Military Time: " + str(Hours) + ":" + str(Minutes) + ":" + str(Seconds) + " DOW = " + str(DOW) 
    rpc(portalAddr, "logEvent", eventString)
    
    
def displayClockDate(): #Status: Ok
    Date    = bcdToDec(readClockReg(4))
    Month   = bcdToDec(readClockReg(5))
    Year    = bcdToDec(readClockReg(6))

    #eventString = "Month = " + str(Month)
    #rpc(portalAddr, "logEvent", eventString)
    
    #eventString = "Date = " + str(Date)
    #rpc(portalAddr, "logEvent", eventString)
    
    #eventString = "Year = " + str(Year)
    #rpc(portalAddr, "logEvent", eventString) 
    
    eventString = "Date: " + str(Month) + "/" + str(Date) + "/" + str(Year) 
    rpc(portalAddr, "logEvent", eventString)
    


def readClockReg(register): #Status: Ok --> Returns an integer - manually convert this integer dec to hex - do not modify !!!!
    """read a single numeric register from the RTC"""
    cmd = buildRtcCmd(register, False)
    i2cWrite(cmd, retries, False)

    cmd = chr( DS3231_RTC_ADDRESS | 1 )
    resultStr = i2cRead(cmd, 1, retries, False)
    
    result = ord( resultStr[0] )
    
    return result


def writeClockReg(register, value):
    """write a numeric register value to the RTC"""
    cmd = buildRtcCmd(register, False)
    cmd += chr(value)
    i2cWrite(cmd, retries, False)
       
    
def decToBcd(val):
    return ( (val/10*16) + (val%10) ) 

def bcdToDec(val):
    return ( (val/16*10) + (val%16) )   


def getTimeDate(): #Status: ok
    global DS3231_SECONDS
    global DS3231_MINUTES
    global DS3231_HOURS
    global DS3231_DOW
    global DS3231_DATE
    global DS3231_MONTH
    global DS3231_YEAR
    
    DS3231_SECONDS = bcdToDec(readClockReg(0) & 0x7F)
    DS3231_MINUTES = bcdToDec(readClockReg(1))
    DS3231_HOURS   = bcdToDec(readClockReg(2) & 0x3F)  # Military Time   
    DS3231_DOW     = bcdToDec(readClockReg(3))
    DS3231_DATE    = bcdToDec(readClockReg(4))
    DS3231_MONTH   = bcdToDec(readClockReg(5))
    DS3231_YEAR    = bcdToDec(readClockReg(6))
    
    # FOR TESTING ONLY !
    #eventString = "Date: " + str(DS3231_MONTH) + "/" + str(DS3231_DATE) + "/" + str(DS3231_YEAR) + " " "Military Time: " + str(DS3231_HOURS) + ":" + str(DS3231_MINUTES) + ":" + str(DS3231_SECONDS) + " DOW = " + str(DS3231_DOW)  
    #rpc(portalAddr, "logEvent", eventString)
    
 
def setTimeDate(hourINT,minuteINT,secondINT,dowINT,monthINT,dateINT,yearINT):
    """set hour(Military Time), minute, second, dow, month, date, year - each must an integer"""
    # Range or input checking is NOT performed. <---------------<<<<<<<<<<<
    writeClockReg(0, decToBcd(secondINT))  # 0 - 59 - Seconds
    writeClockReg(1, decToBcd(minuteINT))  # 0 - 59 - Minutes
    writeClockReg(2, decToBcd(hourINT))    # 0 - 23 - Hours Military Time ONLY!
    writeClockReg(3, decToBcd(dowINT))     # 1 -  7 - DOW - Day of week - Sun = 1
    writeClockReg(4, decToBcd(dateINT))    # 1 - 31 - Date
    writeClockReg(5, decToBcd(monthINT))   # 1 - 12 - Month 
    writeClockReg(6, decToBcd(yearINT))    # 0 - 99 - Year    
        
    """The countdown chain is reset whenever the seconds register
    is written. Write transfers occur on the acknowledge
    from the DS3231. Once the countdown chain is reset, to
    avoid rollover issues the remaining time and date registers
    must be written within 1 second."""

def convertDOWtostr(DOWx):
    global DOW_Str
    if DOWx == 1:
        DOW_Str = 'Sunday-1'
        return DOW_Str            
    if DOWx == 2:
        DOW_Str = 'Monday-2'
        return DOW_Str
    if DOWx == 3:
        DOW_Str = 'Tuesday-3'
        return DOW_Str
    if DOWx == 4:
        DOW_Str = 'Wednesday-4'
        return DOW_Str
    if DOWx == 5:
        DOW_Str = 'Thursday-5'
        return DOW_Str
    if DOWx == 6:
        DOW_Str = 'Friday-6'
        return DOW_Str
    if DOWx == 7:
        DOW_Str = 'Saturday-7'
        return DOW_Str
                                                                
def DS3231_initRTC():
    """Init just the DS3231 (assumes i2cInit() already done)"""
    i2cInit(False) # No pullups = false <--- Must be called on startup hook
    # Note we do not automatically setDate(), setTime()!
    
#--------------------
# Software Alarm 1
#--------------------
def setAlarm1(mon,date,yr,hr,min,sec,dow,almEnabled,almMode):
    global Alarm1_Month 
    global Alarm1_Date 
    global Alarm1_Year 
    global Alarm1_Hours 
    global Alarm1_Minutes 
    global Alarm1_Seconds 
    global Alarm1_DOW 
    global Alarm1_Enable
    global Alarm1_Mode
    
    Alarm1_Month = mon
    Alarm1_Date = date
    Alarm1_Year = yr
    Alarm1_Hours = hr
    Alarm1_Minutes = min
    Alarm1_Seconds = sec
    Alarm1_DOW = dow
    Alarm1_Enable = almEnabled
    Alarm1_Mode = almMode
    
def displayAlarm1():
    global Alarm1_Month 
    global Alarm1_Date 
    global Alarm1_Year 
    global Alarm1_Hours 
    global Alarm1_Minutes 
    global Alarm1_Seconds 
    global Alarm1_DOW 
    global Alarm1_Enable
    global Alarm1_Mode
    
    print  'Month ',Alarm1_Month
    print  'Date ',Alarm1_Date
    print  'Year ',Alarm1_Year
    print  'DOW ',Alarm1_DOW 
    print  'Hour ',Alarm1_Hours
    print  'Minutes ',Alarm1_Minutes
    print  'Seconds ',Alarm1_Seconds
    print  'Alarm1 Enable ',Alarm1_Enable
    print  'Alarm1 Mode ',Alarm1_Mode  
    
def chkAlarm1(mode):
    global DS3231_SECONDS
    global DS3231_MINUTES
    global DS3231_HOURS
    global DS3231_DOW
    global DS3231_DATE
    global DS3231_MONTH
    global DS3231_YEAR
    # 
    global Alarm1_Month 
    global Alarm1_Date 
    global Alarm1_Year 
    global Alarm1_Hours 
    global Alarm1_Minutes 
    global Alarm1_Seconds 
    global Alarm1_DOW 
    
    if mode == 0: # alarm only once - No DOW - uses data/time
        if DS3231_MONTH == Alarm1_Month:
            if DS3231_DATE == Alarm1_Date:
                if DS3231_YEAR == Alarm1_Year:
                    if DS3231_HOURS == Alarm1_Hours:
                        if DS3231_MINUTES == Alarm1_Minutes:
                            if DS3231_SECONDS == Alarm1_Seconds:
                                return True
                            return False
                        return False
                    return False        
                return False           
            return False
        return False
    if mode == 1: # alarm daily at the same time - uses only time
        if DS3231_HOURS == Alarm1_Hours:
            if DS3231_MINUTES == Alarm1_Minutes:
                if DS3231_SECONDS == Alarm1_Seconds:
                    return True
                return False
            return False
        return False     
    if mode == 2: # alarm weekly at the same time - uses DOW and time
        if DS3231_DOW == Alarm1_DOW:
            if DS3231_HOURS == Alarm1_Hours:
                if DS3231_MINUTES == Alarm1_Minutes:
                    if DS3231_SECONDS == Alarm1_Seconds:
                        return True
                    return False
                return False
            return False        
        return False 
        
                    
def enableAlarm1():
    global Alarm1_Enable
    Alarm1_Enable = True
    
def disableAlarm1():                         
    global Alarm1_Enable
    Alarm1_Enable = False
    
#------------------
# Software Alarm 2
#------------------

def setAlarm2(mon,date,yr,hr,min,sec,dow,almEnabled,almMode):
    global Alarm2_Month 
    global Alarm2_Date 
    global Alarm2_Year 
    global Alarm2_Hours 
    global Alarm2_Minutes 
    global Alarm2_Seconds 
    global Alarm2_DOW 
    global Alarm2_Enable
    global Alarm2_Mode
    
    Alarm2_Month = mon
    Alarm2_Date = date
    Alarm2_Year = yr
    Alarm2_Hours = hr
    Alarm2_Minutes = min
    Alarm2_Seconds = sec
    Alarm2_DOW = dow
    Alarm2_Enable = almEnabled
    Alarm2_Mode = almMode
    
def displayAlarm2():
    global Alarm2_Month 
    global Alarm2_Date 
    global Alarm2_Year 
    global Alarm2_Hours 
    global Alarm2_Minutes 
    global Alarm2_Seconds 
    global Alarm2_DOW 
    global Alarm2_Enable
    global Alarm2_Mode
    print  'Month ',Alarm2_Month
    print  'Date ',Alarm2_Date
    print  'Year ',Alarm2_Year
    print  'DOW ',Alarm2_DOW 
    print  'Hour ',Alarm2_Hours
    print  'Minutes ',Alarm2_Minutes
    print  'Seconds ',Alarm2_Seconds
    print  'Alarm2 Enable ',Alarm2_Enable
    print  'Alarm2 Mode ',Alarm2_Mode  
    
def chkAlarm2(mode):
    global DS3231_SECONDS
    global DS3231_MINUTES
    global DS3231_HOURS
    global DS3231_DOW
    global DS3231_DATE
    global DS3231_MONTH
    global DS3231_YEAR
    # 
    global Alarm2_Month 
    global Alarm2_Date 
    global Alarm2_Year 
    global Alarm2_Hours 
    global Alarm2_Minutes 
    global Alarm2_Seconds 
    global Alarm2_DOW 
    
    if mode == 0: # alarm only once - No DOW - uses data/time
        if DS3231_MONTH == Alarm2_Month:
            if DS3231_DATE == Alarm2_Date:
                if DS3231_YEAR == Alarm2_Year:
                    if DS3231_HOURS == Alarm2_Hours:
                        if DS3231_MINUTES == Alarm2_Minutes:
                            if DS3231_SECONDS == Alarm2_Seconds:
                                return True
                            return False
                        return False
                    return False        
                return False           
            return False
        return False
    if mode == 1: # alarm daily at the same time - uses only time
        if DS3231_HOURS == Alarm2_Hours:
            if DS3231_MINUTES == Alarm2_Minutes:
                if DS3231_SECONDS == Alarm2_Seconds:
                    return True
                return False
            return False
        return False     
    if mode == 2: # alarm weekly at the same time - uses DOW and time
        if DS3231_DOW == Alarm2_DOW:
            if DS3231_HOURS == Alarm2_Hours:
                if DS3231_MINUTES == Alarm2_Minutes:
                    if DS3231_SECONDS == Alarm2_Seconds:
                        return True
                    return False
                return False
            return False        
        return False 
        
                    
def enableAlarm2():
    global Alarm2_Enable
    Alarm2_Enable = True
    
def disableAlarm2():                         
    global Alarm2_Enable
    Alarm2_Enable = False    