# Snap Firmware Version: 2.4.19
# Platform RF Engine(Device type): RF200
# Author: Hacker - DuinoMiteMegaAndy
# Application: User hand held RF module 
# Date: 4/4/2012
# Bugs:
# all switches have contact bounce ...
# when a switch is turned on and then switch is turned off there is a double bounce
# digital lockouts are needed to prevent this
# POWER SPECIFICATIONS OF RF200:
# Supply Voltage= 2.7 - 3.6 V
# Transmit Current (Typ@3.3V) =80mA
# Idle/Receive Current (Typ@3.3V) =20mA
# Power-down Current (Typ@3.3V) =1.6uA
#
# To do list:
# Additions:
# Added security key to gd rpc OK
# Platform GPIO for RF200 OK
# Separate garage door activation functions to indentify who did it OK
# Add range LQ checking to handheld <-----<<<<


from synapse.platforms import *
#
# Global Variables
portalAddr = '\x00\x00\x01' # hard-coded address for Portal <------------<<<<<<<<
Mesh_Central_Addr = '\x5C\xCC\x18' # RF200 <-----------------<<<<<<<<<
Garage_Door_Addr = '\x5C\xCC\x30' #<-----------------<<<<<<<<<

kCode = 0
secLockout = False
counterSecs = 0

#Dip switch lockouts
lockout1 = False
lockout2 = False
lockout3 = False
lockout4 = False
lockout5 = False
lockout6 = False
lockout7 = False
lockout8 = False

# Begin Hooks
@setHook(HOOK_STARTUP)
def onStartup():
    # GPIO Outputs
    setPinDir(GPIO_8, True) #LED red
    setPinDir(GPIO_9, True) #LED yel 
    setPinDir(GPIO_10, True) #LED grn
       
    # Set Output State 1=On 0=off (device neg tied to ground)
    writePin(GPIO_8, False)
    writePin(GPIO_9, False)
    writePin(GPIO_10, False)
    # GPIO Inputs
    setPinDir(GPIO_0, False)
    setPinDir(GPIO_1, False)
    setPinDir(GPIO_2, False)
    setPinDir(GPIO_3, False)
    setPinDir(GPIO_4, False)
    setPinDir(GPIO_5, False)
    setPinDir(GPIO_6, False)
    setPinDir(GPIO_7, False)
        
    # GPIO Pullups/pulldowns
    setPinPullup(GPIO_0, True) #pullups 
    setPinPullup(GPIO_1, True) #pullups
    setPinPullup(GPIO_2, True) #pullups
    setPinPullup(GPIO_3, True) #pullups
    setPinPullup(GPIO_4, True) #pullups
    setPinPullup(GPIO_5, True) #pullups
    setPinPullup(GPIO_6, True) #pullups
    setPinPullup(GPIO_7, True) #pullups
    # GPIO Monitor pins
    setRate(1)
    monitorPin(GPIO_0, True) #sw 8  
    monitorPin(GPIO_1, True) #sw 7
    monitorPin(GPIO_2, True) #sw 6
    monitorPin(GPIO_3, True) #sw 5
    monitorPin(GPIO_4, True) #sw 4
    monitorPin(GPIO_5, True) #sw 3
    monitorPin(GPIO_6, True) #sw 2
    monitorPin(GPIO_7, True) #sw 1
    #RPC battery voltage data to mesh network
    w = BATMON()
    x = 'Hand held #1 Bat. Volts = ' 
    y = x + w
    rpc(portalAddr,"logEvent",y) # logevent to portal 
    rpc(Mesh_Central_Addr,'HH1_Bat_Volt',w) # report/log to mesh central
    # Display bat voltage grn = good, yel = warning and red = bad
    bat = showBatLevel()
    if bat == 'good':
        writePin(GPIO_10, True) # green LED ON
    if bat == 'warning':
        writePin(GPIO_9, True) # yellow LED ON
    if bat == 'bad':
        writePin(GPIO_8, True) # red LED ON  

@setHook(HOOK_1S)
def doEverySec(tick):
    global secLockout
    global counterSecs 
    counterSecs += 1
    if counterSecs >= 10 and secLockout == False: # clear bat level leds after 10 seconds
        all_HH1_LEDS_Off() # and clear garage door status after 10 seconds
        counterSecs = 0
    
    
        
@setHook(HOOK_GPIN)
def pinChg(pin, False):
    global lockout1
    global lockout2
    global lockout3
    global lockout4
    global lockout5
    global lockout6
    global lockout7
    global lockout8
    global counterSecs
    # Report that a watched input has been triggered
    if pin == GPIO_7:
        x = readPin(GPIO_7) #SW1 ACTIVATE GARAGE DOOR OPEN OR CLOSE       
        if x == False and lockout1 == False:
            lockout1 = True
            y = 0 # reset security key
            y = scankeyCode() 
            if y == 9: #sw8 and sw1 <-------<<<<<<<<< 
                #print y
                rpc(Garage_Door_Addr,'pulse_Activate_GD_1',True,y)
                y = 0  
    if pin == GPIO_6:
        x = readPin(GPIO_6) #SW2        
        if x == False and lockout2 == False:
            lockout2 = True
    if pin == GPIO_5:
        x = readPin(GPIO_5) #SW3       
        if x == False and lockout3 == False:
            lockout3 = True
    if pin == GPIO_4: 
        x = readPin(GPIO_4) #SW4       
        if x == False and lockout3 == False:
            lockout4 = True     
    if pin == GPIO_3: #SW5
        x = readPin(GPIO_3)
        if x == False and lockout5 == False:
            lockout5 = True
    if pin ==  GPIO_2: #SW6 Display Bat Level   
        x = readPin(GPIO_2)      
        if x == False and lockout3 == False:
            lockout6 = True
            all_HH1_LEDS_Off()
            x = readPin(16)  
            z = showBatLevel()
            if z == 'good':
                writePin(23, True) # green LED ON
            if z == 'warning':
                writePin(12, True) # yellow LED ON
            if z == 'bad':
                writePin(11, True) # red LED ON 
                counterSecs = 0
                
    if pin == GPIO_1:       #SW7 GARAGE DOOR STATUS         
        x = readPin(GPIO_1)      
        if x == False and lockout3 == False:
            lockout7 = True
            all_HH1_LEDS_Off()
            rpc(Garage_Door_Addr,'read_GD_Status')
            counterSecs = 0

    if pin == GPIO_0:               
        x = readPin(GPIO_0)  #SW8 GD activate keyCode       
        if x == False and lockout3 == False:
            lockout8 = True
            
def HH1_red_On():
    writePin(GPIO_8, True)

def HH1_yel_On():            
    writePin(GPIO_9, True)
    
def HH1_grn_On():
    writePin(GPIO_10, True)
    
def all_HH1_LEDS_Off(): 
    writePin(GPIO_8, False) # red off
    writePin(GPIO_9, False) # yel off 
    writePin(GPIO_10, False) # grn off 
     
def all_HH1_LEDS_On(): 
    writePin(GPIO_8, True) # red on
    writePin(GPIO_9, True) # yel on 
    writePin(GPIO_10, True) # grn on                
    
@setHook(HOOK_10MS)
def doEvery10ms(tick):
    global lockout1
    global lockout2
    global lockout3
    global lockout4
    global lockout5
    global lockout6
    global lockout7
    global lockout8
    
    
    x = readPin(GPIO_7) #sw1
    if x == True:
        lockout1 = False
    x = readPin(GPIO_6) #sw2
    if x == True:
        lockout2 = False
    x = readPin(GPIO_5) #sw3
    if x == True:
        lockout3 = False 
    x = readPin(GPIO_4) #sw4
    if x == True:
        lockout4 = False
    x = readPin(GPIO_3) #sw5
    if x == True:
        lockout5 = False
    x = readPin(GPIO_2) #sw6
    if x == True:
        lockout6 = False
    x = readPin(GPIO_1) #sw7
    if x == True:
        lockout7 = False
    x = readPin(GPIO_0) #sw8
    if x == True:
        lockout8 = False                                        
               
  
            
@setHook(HOOK_100MS)    
def timer100msEvent(currentMs):
    pass

def readSw():
    x = readPin(GPIO_7)
    print 'sw1 =',x
    x = readPin(GPIO_6)
    print 'sw2 =',x
    x = readPin(GPIO_5)
    print 'sw3 =',x
    x = readPin(GPIO_4)
    print 'sw4 =',x
    x = readPin(GPIO_3)
    print 'sw5 =',x
    x = readPin(GPIO_2)
    print 'sw6 =',x
    x = readPin(GPIO_1)
    print 'sw7 =',x
    x = readPin(GPIO_0)
    print 'sw8 =',x

def scankeyCode():
    global kCode
    kCode = 0
    sw1 = readPin(GPIO_7) 
    if sw1 == False:
        kCode += 1
    sw2 = readPin(GPIO_6)
    if sw2 == False:
        kCode += 2
    sw3 = readPin(GPIO_5)
    if sw3 == False:
        kCode += 3
    sw4 = readPin(GPIO_4)
    if sw4 == False:
        kCode += 4
    sw5 = readPin(GPIO_3)
    if sw5 == False:
        kCode += 5
    sw6 = readPin(GPIO_2)
    if sw6 == False:
        kCode += 6
    sw7 = readPin(GPIO_1)
    if sw7 == False:
        kCode += 7
    sw8 = readPin(GPIO_0)
    if sw8 == False:
        kCode += 8
    return kCode    
    
               
#BATMON() returns the current Voltage
def lr_vth(nibble):
    bits = '\x00\x01\x02\x03\x04\x05\x06\x07\x08\x09\x0A\x0B\x0C\x0D\x0E\x0F'
    return ord(bits[nibble])
def hr_vth(nibble):
    bits = '\x10\x11\x12\x13\x14\x15\x16\x17\x18\x19\x1A\x1B\x1C\x1D\x1E\x1F'
    return ord(bits[nibble])
def lr_voltage(nibble):
    voltage = ('1.700','1.750','1.800','1.850','1.900','1.950','2.000','2.050','2.100','2.150','2.200','2.250','2.300','2.350','2.400','2.450')
    return voltage[nibble]
def hr_voltage(nibble):
    voltage = ('2.550','2.625','2.700','2.775','2.850','2.925','3.000','3.075','3.150','3.225','3.300','3.375','3.450','3.525','3.600','3.675')
    return voltage[nibble]
def BATMON():
    batval = '0.000'
    # HR 3.675V - 2.550V
    i = 15
    while i > 0:
        poke(0x151, 0x1F & hr_vth(i))
        if peek(0x151) & 32 == 32:
            batval = hr_voltage(i)
            if batval == '0.000':
                i = i - 1
            else:
                i = 0
        i = i - 1
    if batval == '0.000':
        # LR 2.45V - 1.70V
        i = 15
        while i > 0:
            poke(0x151, 0x0F & lr_vth(i))
            if peek(0x151) & 32 == 32:
                batval = lr_voltage(i)
                if batval == '0.000':
                    i = i - 1
                else:
                    i = 0
    return batval

def showBatLevel(): # grn OK, yel warning, red danger
    # POWER SPECIFICATIONS OF RF200:
    # Supply Voltage= 2.7 - 3.6 V
    # Transmit Current (Typ@3.3V) =80mA
    # Idle/Receive Current (Typ@3.3V) =20mA
    # Power-down Current (Typ@3.3V) =1.6uA
    # 2 fresh Alkaline Duracell batteries = 1.6242 x 2 ~ 3.248 VDC
    # batteries feeds a 3.3 v reg MCP1826S-3302 @ 250 mv dropout
    # Bat Volt Range:  '1.700','1.750','1.800','1.850','1.900','1.950','2.000','2.050','2.100','2.150','2.200','2.250','2.300','2.350','2.400','2.450'
    #                  '2.550','2.625','2.700','2.775','2.850','2.925','3.000','3.075','3.150','3.225','3.300','3.375','3.450','3.525','3.600','3.675' 
    # green LED range = 3.375, 3.300, 3.225, 3.150, 3.075, 3.000   
    # yel   LED range =               2.925, 2.850, 2.775
    # red   LED range =               2.770, 2.625, 2.550
    
    x = BATMON()
    level = ''
    #good green LED
    if x == '3.375':
       level = 'good'
       return level
    if x == '3.300':
       level = 'good'
       return level
    if x == '3.225':
       level = 'good'
       return level   
    if x == '3.150':
       level = 'good'
       return level  
    if x == '3.075':
       level = 'good'
       return level 
    if x == '3.000':
       level = 'good'
       return level 
    #warning yel LED    
    if x == '2.925':
       level = 'warning'
       return level
    if x == '2.850':
       level = 'warning'
       return level
    if x == '2.775':
       level = 'warning'
       return level     
    #bad red LED    
    if x == '2.770':
       level = 'bad'
       return level
    if x == '2.625':
       level = 'bad'
       return level
    if x == '2.550':
       level = 'bad'
       return level 
    #unknown
       level = 'bad'
       return level
                
    
    
    
    
        