# Snap Firmware Version: 2.4.19
# Platform RF Engine(Device type): RF200
# Author: Hacker - DuinoMiteMegaAndy
# Application: RF200 analog test 
# Date: 4/4/2012
# Please Note: Software pin(s) and hardware RFET pin(s) are different!
# For RF200 Only!
# HW pin 8 switch input RFE SW pin# 21
# Operation:
# The Mailbox RF200 mesh node is wired as follows:
# The mailbox switch enables the battery power via series 
# normally close (NC) magnetic contact switch and reports the battery voltage
# and RPC to mesh central node. 25 seconds later the RF200 sleeps to save power IF
# not disconnect from power when the mailbox is closed via mechancial magnetic switch. 
# Platform GPIO for RF200 OK
# added 1 sec timer and lockout to prevent contact bounce

# Imports

from synapse.platforms import *
from synapse.pinWakeupATmega128RFA1 import *


# Global Variables
portalAddr='\x00\x00\x01' #<-------------------<<<<<<<<
# Mesh_Central_Addr_RF100 = '\x00\x8C\xFF' #<-----------------<<<<<<<<<
Mesh_Central_Addr_RF200 = '\x5C\xCC\x18'
#------------------------
#   Mailbox - variable(s)
#------------------------

secondCounter = 0
lockout = False
w = '0.000'

 
@setHook(HOOK_STARTUP)
def onStartup():
    global lockout
    global w
    #setRadioRate(1)
    
    # Set HW pin 8 as a watched input
    # SW pin 21 is the software pin! 
    
    setPinDir(GPIO_6, False) # as input
    setPinPullup(GPIO_6, True) # pullup enabled <----- pullup on pin GPIO_6
    # wakeup input is wired via NC switch to ground
    w = BATMON()
    x = 'MB Bat. Volts = ' 
    y = x + w
    rpc(portalAddr,"logEvent",y) # logevent to portal 
    z = "Mailbox Node ReStart"   # report to portal
    if lockout == False:
        rpc(portalAddr,"logEvent",z) 
        rpc(Mesh_Central_Addr_RF200,'MB_Bat_Volt',w) # report/log to mesh central
@setHook(HOOK_1S)
def doEverySec(tick):
    global secondCounter
    global lockout
    global w
    secondCounter += 1             # increment second counter
    if secondCounter == 2 and lockout == False:
        rpc(Mesh_Central_Addr_RF200,'Mail_Status',w) # report/log to mesh central
        lockout = True 
    # showSecCounter() Test only
    if secondCounter >= 35:        # Every 35 seconds power down or deep sleep
        secondCounter = 0          # Reset counter
        #rpc(Mesh_Central_Addr_RF200,'Mail_Status') 
        secondCounter = 0           
        lockout = False      
        RF200_Sleep(GPIO_6,True,0,1,0) # wakeup: pin,enable=True,Level=low sleep mode: 1, ticks 0
    
@setHook(HOOK_100MS)
def timer100msEvent(currentMs):
    pass

#BATMON() returns the current Voltage
def lr_vth(nibble):
    bits = '\x00\x01\x02\x03\x04\x05\x06\x07\x08\x09\x0A\x0B\x0C\x0D\x0E\x0F'
    return ord(bits[nibble])
def hr_vth(nibble):
    bits = '\x10\x11\x12\x13\x14\x15\x16\x17\x18\x19\x1A\x1B\x1C\x1D\x1E\x1F'
    return ord(bits[nibble])
def lr_voltage(nibble):
    voltage = ('1.700','1.750','1.800','1.850','1.900','1.950','2.000','2.050','2.100','2.150','2.200','2.250','2.300','2.350','2.400','2.450')
    return voltage[nibble]
def hr_voltage(nibble):
    voltage = ('2.550','2.625','2.700','2.775','2.850','2.925','3.000','3.075','3.150','3.225','3.300','3.375','3.450','3.525','3.600','3.675')
    return voltage[nibble]
def BATMON():
    batval = '0.000'
    # HR 3.675V - 2.550V
    i = 15
    while i > 0:
        poke(0x151, 0x1F & hr_vth(i))
        if peek(0x151) & 32 == 32:
            batval = hr_voltage(i)
            if batval == '0.000':
                i = i - 1
            else:
                i = 0
        i = i - 1
    if batval == '0.000':
        # LR 2.45V - 1.70V
        i = 15
        while i > 0:
            poke(0x151, 0x0F & lr_vth(i))
            if peek(0x151) & 32 == 32:
                batval = lr_voltage(i)
                if batval == '0.000':
                    i = i - 1
                else:
                    i = 0
    return batval

def RF200_Sleep(pin,enable,polarity,mode,ticks):
    wakeupOn(pin, enable, polarity)
    sleep(mode, ticks)
    
def showSecCounter():
    rpc(portalAddr,"logEvent",secondCounter) # do not log 
    return secondCounter
    


    
          
    