# Snap Firmware Version: 2.4.19
# Platform RF Engine(Device type): RF100
# Author: Hacker - DuinoMiteMegaAndy
# Application: Mesh_Central_Test_R1 
# Date: 4/4/2012
# ---------------------------------------------------
# RF100 UARTO connections to DM serial Com2:
# RF100 GPIO 4 RFET PIN #6 UART0 Tx ---> DM Com2: Rx D2/13 software pin  
# RF100 GPIO 3 RFET PIN #5 UART0 Rx ---> DM Com2: Tx D3/14 software pin  
# RF100 ground RFET PIN #1     ---> DM Com2: ground
# DO NOT USE UART1 on any RF100/200  
# ---> It's used for firmware programming! <---
# ---------------------------------------------------
# POWER SPECIFICATIONS OF RF200:
# Supply Voltage= 2.7 - 3.6 V
# Transmit Current (Typ@3.3V) =80mA
# Idle/Receive Current (Typ@3.3V) =20mA
# Power-down Current (Typ@3.3V) =1.6uA
#
# Platform GPIO for RF200 OK
# Added mailbox counter and flasher
# To do ... Ok
# housekeeping double check garage door status - Ok
# and use yel for limit switch error - Ok
# log all garage door errors to SD - Ok (At system housekeeping time)
# show LED yel warning for low battery for mailbox and handheld 1- OK
# show flash LED yel for bad battery for mailbox and handheld 1- OK
# log all battery errors to SD - OK (At system housekeeping time)
# changed uart0 baudrate from 9600 to 19200 - OK
# added lockout for mailbox - OK

 

from synapse.switchboard import *
from synapse.platforms import *

# Global Variables

# --------------------------
# Node Addresses for RPC
# --------------------------
portalAddr = '\x00\x00\x01'        # hard-coded address for Portal <------------<<<<<<<<
Garage_Door_Addr = '\x5C\xCC\x30'  # RF200 <-----------------<<<<<<<<< 
#---------------------------

MB_Battery_Volts  = '0.000'
HH1_Battery_Volts = '0.000'


secCounter1 = 0
secCounter2 = 0
mailboxCounter = 0
Remote_GD_Status = 0  # 1 = both limit switches active, 2 = mid-travel, 3 = GD Open, 4 = GD close 

# Global RTC DS3231 Time / Date - Integers - default bootup
# Note: The below defaults are also the default DS3231 real time clock registers defaults
# The below global variables will be overwritten by getTimeDate() function.

DS3231_RTC_ADDRESS = 0xD0 # slave address is (0)1101000 which shifts to 1101000(R/W)

DS3231_MONTH    = 1
DS3231_DATE     = 1
DS3231_YEAR     = 0
DS3231_HOURS    = 12
DS3231_MINUTES  = 0
DS3231_SECONDS  = 0
DS3231_DOW      = 1  # Day of week --> Sun = 1, Mon = 2
retries = 1
DOW_Str = ''
DOWx = 1

Alarm1_Month = 1
Alarm1_Date = 1
Alarm1_Year = 0
Alarm1_Hours = 12
Alarm1_Minutes = 0
Alarm1_Seconds = 0
Alarm1_DOW = 1
Alarm1_Enable = False
Alarm1_Mode = 0 # alarm mode 0 = only once, mode 1 = daily, 2 = weekly --> uses DOW

Alarm2_Month = 1
Alarm2_Date = 1
Alarm2_Year = 0
Alarm2_Hours = 12
Alarm2_Minutes = 0
Alarm2_Seconds = 0
Alarm2_DOW = 1
Alarm2_Enable = False
Alarm2_Mode = 0 # alarm mode 0 = only once, mode 1 = daily, 2 = weekly --> uses DOW

Run_LED = GPIO_0
Mail_LED = GPIO_1
GD_Open_LED = GPIO_2
GD_Close_LED = GPIO_11
GD_Error_LED = GPIO_6
Bat1_LED = GPIO_7
Bat2_LED = GPIO_8  
Bat3_LED = GPIO_10
Piezo = GPIO_9


enableMailflash = False
enableBat1flash = False
enableBat2flash = False
enableBat3flash = False

mailboxLockout = False


# Snappy Start 
@setHook(HOOK_STARTUP)
def onStartup():
    setPinDir(Run_LED, True)
    setPinDir(Mail_LED, True) 
    setPinDir(GD_Open_LED, True)
    setPinDir(GD_Close_LED, True)
    setPinDir(GD_Error_LED, True) 
    setPinDir(Bat1_LED, True)
    setPinDir(Bat2_LED, True) 
    setPinDir(Bat3_LED, True)
    setPinDir(Piezo, True) 
    # low = Off 
    writePin(Run_LED, False)
    writePin(Mail_LED, False)
    writePin(GD_Open_LED, False)
    writePin(GD_Close_LED, False)
    writePin(GD_Error_LED, False)
    writePin(Bat1_LED, False)
    writePin(Bat2_LED, False)
    writePin(Bat3_LED, False)
    writePin(Piezo, False)
    
    # I2C GPIO_17/18 used for DS3231
    DS3231_initRTC() # <----- NEEDED--<<<<<  Init I2C RTC - no pullups
    
    #set Uart0 to 9600 on RF200 
    initUart(0,9600) #<---------------<<<<<<<< was
    #initUart(0,19200) #<---------------<<<<<<<< now
    # All snappy print statements flow to UART0
    crossConnect(DS_UART0, DS_STDIO)
    # pulse piezo
    Piezo_Pulse()
    
@setHook(HOOK_STDIN)
def getInput(data):
    # Diagnostic command from MM Basic Controller
    pass
    #if data == 'Cmd1':
        #writePin(Bat3_LED, True) 
        #print 'MC_OK'
    #if data == 'piezo_Pulse': 
        #Piezo_Pulse()    
        
@setHook(HOOK_GPIN)
def onPin(pin, isSet):
    # Report that a watched input has been triggered
    pass
    
                

@setHook(HOOK_1S)
def doEverySec(tick):
    global secCounter1
    global secCounter2
    global mailboxCounter
    global enableMailflash
    global mailboxLockout
    
    secCounter1 += 1
    secCounter2 += 1
    
    getTimeDate() # Read I2C time / date every second
    convertDOWtostr(DS3231_DOW) # convert dow nbr to str
    # System Housekeeping
    if DS3231_HOURS == 23: # 12:55:0 <------- everyday by RTC
        if DS3231_MINUTES == 55:
            if DS3231_SECONDS == 0:
                #clear Mailbox LED
                enableMailflash = False
                writePin(Mail_LED, False)
                mailboxCounter = 0
    if DS3231_HOURS == 23: # 12:55:5 <------- everyday by RTC
        if DS3231_MINUTES == 55:
            if DS3231_SECONDS == 5:
                checkBat1Level() # Mailbox bat                
    if DS3231_HOURS == 23: # 12:55:10 <------- everyday by RTC
        if DS3231_MINUTES == 55:
            if DS3231_SECONDS == 10:
                checkBat2Level() # Handheld 1 bat 
    if DS3231_HOURS == 23: # 12:55:15 <------- everyday by RTC
        if DS3231_MINUTES == 55:
            if DS3231_SECONDS == 15:
                #get garage door status 
                writePin(GD_Open_LED, False) #off
                writePin(GD_Close_LED, False) #off
                writePin(GD_Error_LED, False) #off
                get_GD_Status() # RPC call
    if DS3231_HOURS == 23: # 12:55:20 <------- everyday by RTC
        if DS3231_MINUTES == 55:
            if DS3231_SECONDS == 20:
                #process garage door status and log errors
                if  Remote_GD_Status == 1: # both GD limit switches are False (close) --> impossible?
                    writePin(GD_Error_LED, True) #yel LED on
                    print 'M1'
                    #print 'Sys_Garage Door Error 1'
                if  Remote_GD_Status == 2: # both GD limit switches are True (open) --> mid-travel OR traveling 
                                   # OR one switch is bad OR garage door is partically open
                    writePin(GD_Error_LED, True) #yel LED on
                    print 'M2'
                    #print 'Sys_Garage Door Error 2'
                if  Remote_GD_Status == 3: # garage door open
                    writePin(GD_Open_LED, True) #red LED on
                    print 'M3'
                    #print 'Sys_Garage Door Open'
                if  Remote_GD_Status == 4: # garage door close
                    writePin(GD_Close_LED, True) #green LED on
                    print 'M4'
                    #print 'Sys_Garage Door Close'                    
    # Run green LED 1s heartbeat        
    x = readPin(Run_LED)
    if x == True:
        writePin(Run_LED, False)
    if x == False:
        writePin(Run_LED, True)
    # Once an hour    
    if secCounter1 >= 3599:  # Check garage door status once an hour
        # Get garage door status
        writePin(GD_Open_LED, False) #off
        writePin(GD_Close_LED, False) #off
        writePin(GD_Error_LED, False) #off
        get_GD_Status() # RPC call
    if secCounter1 == 3600:            
        if  Remote_GD_Status == 1: # both GD limit switches are False (close) --> impossible?
            writePin(GD_Error_LED, True) #yel LED on
        if  Remote_GD_Status == 2: # both GD limit switches are True (open) --> mid-travel OR traveling 
                                   # OR one switch is bad OR garage door is partically open
            writePin(GD_Error_LED, True) #yel LED on
        if  Remote_GD_Status == 3: # garage door open
            writePin(GD_Open_LED, True) #red LED on
        if  Remote_GD_Status == 4: # garage door close
            writePin(GD_Close_LED, True) #green LED on
            secCounter1 = 0         # reset sec counter every hour
            
    if secCounter2 >= 50:
        secondCounter2 = 0
        mailboxLockout = False
                
@setHook(HOOK_100MS)    
def timer100msEvent(currentMs):
    global enableMailflash
    global enableBat1flash
    global enableBat2flash
    global enableBat3flash
    
    
    if enableMailflash == True:
        x = readPin(Mail_LED)
        if x == True:
            writePin(Mail_LED, False)
        if x == False:
            writePin(Mail_LED, True)
    if enableBat1flash == True:
        x = readPin(Bat1_LED)
        if x == True:
            writePin(Bat1_LED, False)
        if x == False:
            writePin(Bat1_LED, True)
    if enableBat2flash == True:
        x = readPin(Bat2_LED)
        if x == True:
            writePin(Bat2_LED, False)
        if x == False:
            writePin(Bat2_LED, True)
    if enableBat3flash == True:
        x = readPin(Bat3_LED)
        if x == True:
            writePin(Bat3_LED, False)
        if x == False:
            writePin(Bat3_LED, True)            
    
def switchBack():
    # Switching SDIO in portal menu you need to use this to switch back
    crossConnect(DS_UART0, DS_STDIO)
    
def Mail_Status(volts):
    global mailboxCounter
    global enableMailflash
    global mailboxLockout
    #global MB_Battery_Volts 
    # RPC - called from mailbox peer node
    # send message to SDIO Tx via print
    #MB_Battery_Volts = volts
    if mailboxLockout == False: 
        mailboxCounter += 1
        if mailboxCounter == 1:
            mailboxLockout = True
            writePin(Mail_LED, True) 
            Piezo_Pulse()
            print 'M5'
            #print 'You got USPS Mail'
        if mailboxCounter >= 2:
            mailboxLockout = True
            print 'M6'
            #print 'Someone got your Mail'
            #flash mail status led
            enableMailflash = True
            Piezo_Pulse()
        
def clear_MB_LED():
    global enableFlash
    global mailboxCounter
    mailboxCounter = 0
    enableFlash = False
    writePin(Mail_LED, False)
    
def displayMailbox_Counter():
    global mailboxCounter
    print mailboxCounter
    

def GD_Open_Status():
    # RPC - called from garage door peer node
    # send message to SDIO Tx via print
    writePin(GD_Open_LED, True) 
    writePin(GD_Close_LED, False)
    print 'M7'
    #print 'Garage Door Open'    
    Piezo_Pulse()    
    
def GD_Close_Status():
    # RPC - called from garage door peer node
    # send message to SDIO Tx via print
    writePin(GD_Close_LED, True) 
    writePin(GD_Open_LED, False)
    print 'M8'
    #print 'Garage Door Close'    
    Piezo_Pulse()    
    
    
def GD_Activate1():
    # RPC - called from garage door peer node
    # send message to SDIO Tx via print
    print 'M9'    
    #print 'Garage Door HH1 Activate' 
    
def GD_Activate2():
    # RPC - called from garage door peer node
    # send message to SDIO Tx via print
    print 'M10'    
    #print 'Garage Door MC Activate'     
    
def GD_Status(nbr): # RPC called from garage door peer 
    global Remote_GD_Status
    Remote_GD_Status = 0
    Remote_GD_Status = nbr
    return nbr

def get_GD_Status():
    rpc(Garage_Door_Addr,'read_GD_Status')
    
def display_GD_Status():
    global Remote_GD_Status
    return Remote_GD_Status    

def Piezo_ON():
    # RPC - called from x peer node
    # send message to SDIO Tx via print
    # Source mode 1=On 0=off 
    writePin(Piezo, True)
    
def Piezo_Pulse():
    # RPC - called from x peer node
    # send message to SDIO Tx via print
    # Pulse the Piezo for 1000 msec.
    pulsePin(Piezo, 250, True)
  
def Piezo_OFF():
    # RPC - called from x peer node
    # send message to SDIO Tx via print
    # Source mode 1=On 0=off 
    writePin(Piezo, False)
#------------------------------------------------------ 
# Remote battery volts
# --------------------
def displayHH1BatVolts(): 
    rpc(portalAddr,"logEvent",HH1_Battery_Volts)
    
def displayMailboxBatVolts(): 
    rpc(portalAddr,"logEvent",MB_Battery_Volts)   
        
def HH1_Bat_Volt(volts): # From HandHeld1 RPC
    global HH1_Battery_Volts
    HH1_Battery_Volts = volts
    
def MB_Bat_Volt(volts): # From Mailbox RPC
    global MB_Battery_Volts
    MB_Battery_Volts = volts

def checkBat1Level(): #mailbox
    global enableBat1flash
    bat1 = BatLevel(MB_Battery_Volts)
    if bat1 == 'good':
        pass
    if bat1 == 'warning':
        writePin(Bat1_LED, True)
        #Log
        print 'M11'
        #print 'Sys_MB Bat Warning'
    if bat1 == 'bad':
        enableBat1flash = True
        #Log
        print 'M12'   
        #print 'Sys_MB Bat Bad' 
def checkBat2Level(): #handheld 1
    global enableBat2flash
    bat2 = BatLevel(HH1_Battery_Volts)
    if bat2 == 'good':
        pass
    if bat2 == 'warning':
        writePin(Bat2_LED, True)
        #Log
        print 'M13'
        #print 'Sys_HH1 Bat Warning'
    if bat2 == 'bad':
        enableBat2flash = True
        #Log 
        print 'M14'     
        #print 'Sys_HH1 Bat Bad'     
    
def BatLevel(volts): 
    # POWER SPECIFICATIONS OF RF200:
    # Supply Voltage= 2.7 - 3.6 V
    # Transmit Current (Typ@3.3V) =80mA
    # Idle/Receive Current (Typ@3.3V) =20mA
    # Power-down Current (Typ@3.3V) =1.6uA
    # 2 fresh Alkaline Duracell batteries = 1.6242 x 2 ~ 3.248 VDC
    # batteries feeds a 3.3 v reg MCP1826S-3302 @ 250 mv dropout
    # Bat Volt Range:  '1.700','1.750','1.800','1.850','1.900','1.950','2.000','2.050','2.100','2.150','2.200','2.250','2.300','2.350','2.400','2.450'
    #                  '2.550','2.625','2.700','2.775','2.850','2.925','3.000','3.075','3.150','3.225','3.300','3.375','3.450','3.525','3.600','3.675' 
    # good    range = 3.375, 3.300, 3.225, 3.150, 3.075, 3.000   
    # warning range = 2.925, 2.850, 2.775
    # bad     range = 2.770, 2.625, 2.550
    
    x = volts 
    level = ''
    #good green LED
    if x == '3.375':
       level = 'good'
       return level
    if x == '3.300':
       level = 'good'
       return level
    if x == '3.225':
       level = 'good'
       return level   
    if x == '3.150':
       level = 'good'
       return level  
    if x == '3.075':
       level = 'good'
       return level 
    if x == '3.000':
       level = 'good'
       return level 
    #warning yel LED    
    if x == '2.925':
       level = 'warning'
       return level
    if x == '2.850':
       level = 'warning'
       return level
    if x == '2.775':
       level = 'warning'
       return level     
    #bad red LED    
    if x == '2.770':
       level = 'bad'
       return level
    if x == '2.625':
       level = 'bad'
       return level
    if x == '2.550':
       level = 'bad'
       return level 
    #unknown
    if x == '0.000': # not updated by remotes ?
       level = 'good'
       return level    
    level = 'bad'
    return level
    
#---------------------------------------------------------              
def Test_GD_Close_Green_Status_Led_On():
    writePin(GD_Close_LED, True)              

def Test_GD_Open_Red_Status_Led_On():
    writePin(GD_Open_LED, True)
    
def Test_GD_Close_Green_Status_Led_Off():
    writePin(GD_Close_LED, False)              

def Test_GD_Open_Red_Status_Led_Off():
    writePin(GD_Open_LED, False)    

def LED_Test_On():
    writePin(Run_LED, True)
    writePin(Mail_LED, True)
    writePin(GD_Open_LED, True)
    writePin(GD_Close_LED, True)
    writePin(GD_Error_LED, True)
    writePin(Bat1_LED, True)
    writePin(Bat2_LED, True)
    writePin(Bat3_LED, True)
        

def LED_Test_Off():
    writePin(Run_LED, False)
    writePin(Mail_LED, False)
    writePin(GD_Open_LED, False)
    writePin(GD_Close_LED, False)
    writePin(GD_Error_LED, False)
    writePin(Bat1_LED, False)
    writePin(Bat2_LED, False)
    writePin(Bat3_LED, False)
    
    writePin(GPIO_0,False)
    writePin(GPIO_1,False)
    writePin(GPIO_2,False)
    writePin(GPIO_3,False)
    writePin(GPIO_6,False)
    writePin(GPIO_7,False)
    writePin(GPIO_8,False)
    writePin(GPIO_10,False)
    writePin(GPIO_11,False)
        
def LED_Test_GPIO_0():
    writePin(GPIO_0, True)

def LED_Test_GPIO_1():
    writePin(GPIO_1, True)
        
def LED_Test_GPIO_2():
    writePin(GPIO_2, True)

def LED_Test_GPIO_6():
    writePin(GPIO_6, True)

def LED_Test_GPIO_7():
    writePin(GPIO_7, True)

def LED_Test_GPIO_8():
    writePin(GPIO_8, True)
        
def LED_Test_GPIO_10():
    writePin(GPIO_10, True)
    
def LED_Test_GPIO_11():
    writePin(GPIO_11, True)

#--------------------------------------------------------------------
def buildRtcCmd(registerAddress, isRead):
    """internal helper routine"""
    slaveAddress = DS3231_RTC_ADDRESS
    if isRead:
        slaveAddress |= 1 # read
    cmd = ""
    cmd += chr( slaveAddress )
    cmd += chr( registerAddress )

    return cmd

def readClock(firstReg, numRegs):  # does not work ????  
    """read a string of registers from the RTC"""
    cmd = buildRtcCmd(firstReg, False)  
    i2cWrite(cmd, retries, False)  

    cmd = chr( DS3231_RTC_ADDRESS | 1 )
    result = i2cRead(cmd, numRegs, retries, False) 
             
    return result

def displayClockTime(): #Status: Ok
    Seconds = bcdToDec(readClockReg(0) & 0x7F)
    Minutes = bcdToDec(readClockReg(1))
    Hours   = bcdToDec(readClockReg(2) & 0x3F)    
    DOW     = bcdToDec(readClockReg(3))
       
    #eventString = "Hours = " + str(Hours)
    #rpc(portalAddr, "logEvent", eventString)
    
    #eventString = "Minutes = " + str(Minutes)
    #rpc(portalAddr, "logEvent", eventString)
    
    #eventString = "Seconds = " + str(Seconds)
    #rpc(portalAddr, "logEvent", eventString)
    
    #eventString = "Day of Week = " + str(DOW)
    #rpc(portalAddr, "logEvent", eventString)
    
    eventString = "Military Time: " + str(Hours) + ":" + str(Minutes) + ":" + str(Seconds) + " DOW = " + str(DOW) 
    rpc(portalAddr, "logEvent", eventString)
    
    
def displayClockDate(): #Status: Ok
    Date    = bcdToDec(readClockReg(4))
    Month   = bcdToDec(readClockReg(5))
    Year    = bcdToDec(readClockReg(6))

    #eventString = "Month = " + str(Month)
    #rpc(portalAddr, "logEvent", eventString)
    
    #eventString = "Date = " + str(Date)
    #rpc(portalAddr, "logEvent", eventString)
    
    #eventString = "Year = " + str(Year)
    #rpc(portalAddr, "logEvent", eventString) 
    
    eventString = "Date: " + str(Month) + "/" + str(Date) + "/" + str(Year) 
    rpc(portalAddr, "logEvent", eventString)
    


def readClockReg(register): #Status: Ok --> Returns an integer - manually convert this integer dec to hex - do not modify !!!!
    """read a single numeric register from the RTC"""
    cmd = buildRtcCmd(register, False)
    i2cWrite(cmd, retries, False)

    cmd = chr( DS3231_RTC_ADDRESS | 1 )
    resultStr = i2cRead(cmd, 1, retries, False)
    
    result = ord( resultStr[0] )
    
    return result


def writeClockReg(register, value):
    """write a numeric register value to the RTC"""
    cmd = buildRtcCmd(register, False)
    cmd += chr(value)
    i2cWrite(cmd, retries, False)
       
    
def decToBcd(val):
    return ( (val/10*16) + (val%10) ) 

def bcdToDec(val):
    return ( (val/16*10) + (val%16) )   


def getTimeDate(): #Status: ok
    global DS3231_SECONDS
    global DS3231_MINUTES
    global DS3231_HOURS
    global DS3231_DOW
    global DS3231_DATE
    global DS3231_MONTH
    global DS3231_YEAR
    
    DS3231_SECONDS = bcdToDec(readClockReg(0) & 0x7F)
    DS3231_MINUTES = bcdToDec(readClockReg(1))
    DS3231_HOURS   = bcdToDec(readClockReg(2) & 0x3F)  # Military Time   
    DS3231_DOW     = bcdToDec(readClockReg(3))
    DS3231_DATE    = bcdToDec(readClockReg(4))
    DS3231_MONTH   = bcdToDec(readClockReg(5))
    DS3231_YEAR    = bcdToDec(readClockReg(6))
    
    # FOR TESTING ONLY !
    #eventString = "Date: " + str(DS3231_MONTH) + "/" + str(DS3231_DATE) + "/" + str(DS3231_YEAR) + " " "Military Time: " + str(DS3231_HOURS) + ":" + str(DS3231_MINUTES) + ":" + str(DS3231_SECONDS) + " DOW = " + str(DS3231_DOW)  
    #rpc(portalAddr, "logEvent", eventString)
    
 
def setTimeDate(hourINT,minuteINT,secondINT,dowINT,monthINT,dateINT,yearINT):
    """set hour(Military Time), minute, second, dow, month, date, year - each must an integer"""
    # Range or input checking is NOT performed. <---------------<<<<<<<<<<<
    writeClockReg(0, decToBcd(secondINT))  # 0 - 59 - Seconds
    writeClockReg(1, decToBcd(minuteINT))  # 0 - 59 - Minutes
    writeClockReg(2, decToBcd(hourINT))    # 0 - 23 - Hours Military Time ONLY!
    writeClockReg(3, decToBcd(dowINT))     # 1 -  7 - DOW - Day of week - Sun = 1
    writeClockReg(4, decToBcd(dateINT))    # 1 - 31 - Date
    writeClockReg(5, decToBcd(monthINT))   # 1 - 12 - Month 
    writeClockReg(6, decToBcd(yearINT))    # 0 - 99 - Year    
        
    """The countdown chain is reset whenever the seconds register
    is written. Write transfers occur on the acknowledge
    from the DS3231. Once the countdown chain is reset, to
    avoid rollover issues the remaining time and date registers
    must be written within 1 second."""

def convertDOWtostr(DOWx):
    global DOW_Str
    if DOWx == 1:
        DOW_Str = 'Sunday-1'
        return DOW_Str            
    if DOWx == 2:
        DOW_Str = 'Monday-2'
        return DOW_Str
    if DOWx == 3:
        DOW_Str = 'Tuesday-3'
        return DOW_Str
    if DOWx == 4:
        DOW_Str = 'Wednesday-4'
        return DOW_Str
    if DOWx == 5:
        DOW_Str = 'Thursday-5'
        return DOW_Str
    if DOWx == 6:
        DOW_Str = 'Friday-6'
        return DOW_Str
    if DOWx == 7:
        DOW_Str = 'Saturday-7'
        return DOW_Str
                                                                
def DS3231_initRTC():
    """Init just the DS3231 (assumes i2cInit() already done)"""
    i2cInit(False) # No pullups = false <--- Must be called on startup hook
    # Note we do not automatically setDate(), setTime()!
    
#--------------------
# Software Alarm 1
#--------------------
def setAlarm1(mon,date,yr,hr,min,sec,dow,almEnabled,almMode):
    global Alarm1_Month 
    global Alarm1_Date 
    global Alarm1_Year 
    global Alarm1_Hours 
    global Alarm1_Minutes 
    global Alarm1_Seconds 
    global Alarm1_DOW 
    global Alarm1_Enable
    global Alarm1_Mode
    
    Alarm1_Month = mon
    Alarm1_Date = date
    Alarm1_Year = yr
    Alarm1_Hours = hr
    Alarm1_Minutes = min
    Alarm1_Seconds = sec
    Alarm1_DOW = dow
    Alarm1_Enable = almEnabled
    Alarm1_Mode = almMode
    
def displayAlarm1():
    global Alarm1_Month 
    global Alarm1_Date 
    global Alarm1_Year 
    global Alarm1_Hours 
    global Alarm1_Minutes 
    global Alarm1_Seconds 
    global Alarm1_DOW 
    global Alarm1_Enable
    global Alarm1_Mode
    
    print  'Month ',Alarm1_Month
    print  'Date ',Alarm1_Date
    print  'Year ',Alarm1_Year
    print  'DOW ',Alarm1_DOW 
    print  'Hour ',Alarm1_Hours
    print  'Minutes ',Alarm1_Minutes
    print  'Seconds ',Alarm1_Seconds
    print  'Alarm1 Enable ',Alarm1_Enable
    print  'Alarm1 Mode ',Alarm1_Mode  
    
def chkAlarm1(mode):
    global DS3231_SECONDS
    global DS3231_MINUTES
    global DS3231_HOURS
    global DS3231_DOW
    global DS3231_DATE
    global DS3231_MONTH
    global DS3231_YEAR
    # 
    global Alarm1_Month 
    global Alarm1_Date 
    global Alarm1_Year 
    global Alarm1_Hours 
    global Alarm1_Minutes 
    global Alarm1_Seconds 
    global Alarm1_DOW 
    
    if mode == 0: # alarm only once - No DOW - uses data/time
        if DS3231_MONTH == Alarm1_Month:
            if DS3231_DATE == Alarm1_Date:
                if DS3231_YEAR == Alarm1_Year:
                    if DS3231_HOURS == Alarm1_Hours:
                        if DS3231_MINUTES == Alarm1_Minutes:
                            if DS3231_SECONDS == Alarm1_Seconds:
                                return True
                            return False
                        return False
                    return False        
                return False           
            return False
        return False
    if mode == 1: # alarm daily at the same time - uses only time
        if DS3231_HOURS == Alarm1_Hours:
            if DS3231_MINUTES == Alarm1_Minutes:
                if DS3231_SECONDS == Alarm1_Seconds:
                    return True
                return False
            return False
        return False     
    if mode == 2: # alarm weekly at the same time - uses DOW and time
        if DS3231_DOW == Alarm1_DOW:
            if DS3231_HOURS == Alarm1_Hours:
                if DS3231_MINUTES == Alarm1_Minutes:
                    if DS3231_SECONDS == Alarm1_Seconds:
                        return True
                    return False
                return False
            return False        
        return False 
        
                    
def enableAlarm1():
    global Alarm1_Enable
    Alarm1_Enable = True
    
def disableAlarm1():                         
    global Alarm1_Enable
    Alarm1_Enable = False
    
#------------------
# Software Alarm 2
#------------------

def setAlarm2(mon,date,yr,hr,min,sec,dow,almEnabled,almMode):
    global Alarm2_Month 
    global Alarm2_Date 
    global Alarm2_Year 
    global Alarm2_Hours 
    global Alarm2_Minutes 
    global Alarm2_Seconds 
    global Alarm2_DOW 
    global Alarm2_Enable
    global Alarm2_Mode
    
    Alarm2_Month = mon
    Alarm2_Date = date
    Alarm2_Year = yr
    Alarm2_Hours = hr
    Alarm2_Minutes = min
    Alarm2_Seconds = sec
    Alarm2_DOW = dow
    Alarm2_Enable = almEnabled
    Alarm2_Mode = almMode
    
def displayAlarm2():
    global Alarm2_Month 
    global Alarm2_Date 
    global Alarm2_Year 
    global Alarm2_Hours 
    global Alarm2_Minutes 
    global Alarm2_Seconds 
    global Alarm2_DOW 
    global Alarm2_Enable
    global Alarm2_Mode
    print  'Month ',Alarm2_Month
    print  'Date ',Alarm2_Date
    print  'Year ',Alarm2_Year
    print  'DOW ',Alarm2_DOW 
    print  'Hour ',Alarm2_Hours
    print  'Minutes ',Alarm2_Minutes
    print  'Seconds ',Alarm2_Seconds
    print  'Alarm2 Enable ',Alarm2_Enable
    print  'Alarm2 Mode ',Alarm2_Mode  
    
def chkAlarm2(mode):
    global DS3231_SECONDS
    global DS3231_MINUTES
    global DS3231_HOURS
    global DS3231_DOW
    global DS3231_DATE
    global DS3231_MONTH
    global DS3231_YEAR
    # 
    global Alarm2_Month 
    global Alarm2_Date 
    global Alarm2_Year 
    global Alarm2_Hours 
    global Alarm2_Minutes 
    global Alarm2_Seconds 
    global Alarm2_DOW 
    
    if mode == 0: # alarm only once - No DOW - uses data/time
        if DS3231_MONTH == Alarm2_Month:
            if DS3231_DATE == Alarm2_Date:
                if DS3231_YEAR == Alarm2_Year:
                    if DS3231_HOURS == Alarm2_Hours:
                        if DS3231_MINUTES == Alarm2_Minutes:
                            if DS3231_SECONDS == Alarm2_Seconds:
                                return True
                            return False
                        return False
                    return False        
                return False           
            return False
        return False
    if mode == 1: # alarm daily at the same time - uses only time
        if DS3231_HOURS == Alarm2_Hours:
            if DS3231_MINUTES == Alarm2_Minutes:
                if DS3231_SECONDS == Alarm2_Seconds:
                    return True
                return False
            return False
        return False     
    if mode == 2: # alarm weekly at the same time - uses DOW and time
        if DS3231_DOW == Alarm2_DOW:
            if DS3231_HOURS == Alarm2_Hours:
                if DS3231_MINUTES == Alarm2_Minutes:
                    if DS3231_SECONDS == Alarm2_Seconds:
                        return True
                    return False
                return False
            return False        
        return False 
        
                    
def enableAlarm2():
    global Alarm2_Enable
    Alarm2_Enable = True
    
def disableAlarm2():                         
    global Alarm2_Enable
    Alarm2_Enable = False                    
            
        
    
    
    
    
    
    